define(
//begin v1.x content
{
	"HKD_displayName": "Dólar de Hong Kong",
	"CNY_displayName": "Yuan chinês",
	"JPY_displayName": "Iene japonês",
	"JPY_symbol": "JP¥",
	"USD_displayName": "Dólar americano",
	"CAD_symbol": "CA$",
	"GBP_displayName": "Libra esterlina",
	"CHF_displayName": "Franco suíço",
	"CNY_symbol": "CN¥",
	"EUR_displayName": "Euro",
	"GBP_symbol": "£",
	"CAD_displayName": "Dólar canadense",
	"USD_symbol": "US$",
	"EUR_symbol": "€",
	"AUD_displayName": "Dólar australiano",
	"CHF_symbol": "CHF",
	"HKD_symbol": "HK$",
	"AUD_symbol": "AU$"
}
//end v1.x content
);